(v0.5.0)=
### 0.5.0 {small}`9 February, 2018`

- inform about duplicates in {class}`~anndata.AnnData.var_names` and resolve them using {func}`~anndata.AnnData.var_names_make_unique`
- automatically remove unused categories after slicing
- read/write [.loom](https://loompy.org) files using loompy 2
- fixed read/write for a few text file formats
- read [UMI tools] files: {func}`~anndata.io.read_umi_tools`

[umi tools]: https://github.com/CGATOxford/UMI-tools
